<?php /** @var FreshRSS_View $this */ ?>
<main class="post content">
	<?php if ($this->can_register) { ?>
		<a href="<?= _url('auth', 'register') ?>">
			<?= _t('gen.action.back') ?>
		</a>
	<?php } else { ?>
		<a href="<?= _url('index', 'index') ?>">
			<?= _t('gen.action.back') ?>
		</a>
	<?php } ?>

	<?= $this->terms_of_service ?>
</main>
