<?php /** @var FreshRSS_View $this */ ?>
<?php
header('Content-Type: application/json; charset=UTF-8');

$url = array(
	'c' => Minz_Request::controllerName(),
	'a' => Minz_Request::actionName(),
	'params' => $_GET,
);

$url['params']['is_favorite'] = Minz_Request::param('is_favorite', true) ? '0' : '1';

FreshRSS::loadStylesAndScripts();
echo json_encode(array(
		'url' => str_ireplace('&amp;', '&', Minz_Url::display($url)),
		'icon' => _i($url['params']['is_favorite'] === '1' ? 'non-starred' : 'starred')
	));
