<?php
	/** @var FreshRSS_View $this */
	$url_next = Minz_Request::currentRequest();
	$url_next['params']['next'] = FreshRSS_Context::$next_id;
	$url_next['params']['state'] = FreshRSS_Context::$state;
	$url_next['params']['ajax'] = 1;

	$url_mark_read = array(
		'c' => 'entry',
		'a' => 'read',
		'params' => array(
			'get' => FreshRSS_Context::currentGet(),
			'nextGet' => FreshRSS_Context::$next_get,
			'idMax' => FreshRSS_Context::$id_max,
			'search' => htmlspecialchars_decode(FreshRSS_Context::$search, ENT_QUOTES),
			'state' => FreshRSS_Context::$state,
		)
	);
?>

<?php
$hasAccess = FreshRSS_Auth::hasAccess();
if ($hasAccess) { ?>
<form id="stream-footer" action="" method="post">
<input type="hidden" name="_csrf" value="<?= FreshRSS_Auth::csrfToken() ?>" />
<?php } else { ?>
<div id="stream-footer">
<?php }?>
	<div class="stream-footer-inner">
	<?php if (FreshRSS_Context::$next_id) { ?>
		<button id="load_more" type="submit" class="btn" formaction="<?= Minz_Url::display($url_next) ?>"><?= _t('gen.stream.load_more') ?></button>
	<?php } elseif ($hasAccess) { ?>
		<?= _t('gen.stream.nothing_to_load') ?><br />
		<button id="bigMarkAsRead"
			class="as-link <?= FreshRSS_Context::$user_conf->reading_confirm ? 'confirm" disabled="disabled' : '' ?>"
			form="stream-footer"
			formaction="<?= Minz_Url::display($url_mark_read) ?>"
			type="submit">
			<span class="bigTick">✓</span><br />
			<span class="markAllRead"><?= _t('gen.stream.mark_all_read') ?></span>
			<?php if (FreshRSS_Context::$user_conf->onread_jump_next) { ?>
				<div class="jumpNext"><?= _t('conf.reading.jump_next') ?></div>
			<?php } ?>
		</button>
	<?php } else { ?>
		<?= _t('gen.stream.nothing_to_load') ?><br />
	<?php } ?>
	</div>
<?php if ($hasAccess) { ?>
</form>
<?php } else {?>
</div>
<?php }?>
