<header class="header">
	<div class="item title">
		<a href="<?= _url('index', 'index') ?>">
			<?php if (FreshRSS_Context::$system_conf->logo_html == '') { ?>
				<img class="logo" src="<?= _i('FreshRSS-logo', FreshRSS_Themes::ICON_URL) ?>" alt="FreshRSS" loading="lazy" />
			<?php
				} else {
					echo FreshRSS_Context::$system_conf->logo_html;
				}
			?>
		</a>
	</div>

	<div class="item search">
		<?php if (FreshRSS_Auth::hasAccess() || FreshRSS_Context::$system_conf->allow_anonymous) { ?>
		<form action="<?= _url('index', 'index') ?>" method="get">
			<div class="stick">
				<input type="search" name="search" id="search"
					value="<?= htmlspecialchars(htmlspecialchars_decode(FreshRSS_Context::$search, ENT_QUOTES), ENT_COMPAT, 'UTF-8') ?>"
					placeholder="<?= _t('gen.menu.search') ?>" />

				<?php $param_a = Minz_Request::actionName(); ?>
				<?php if (in_array($param_a, ['normal', 'global', 'reader'])) { ?>
				<input type="hidden" name="a" value="<?= $param_a ?>" />
				<?php } ?>

				<?php $get = Minz_Request::param('get', ''); ?>
				<?php if ($get != '') { ?>
				<input type="hidden" name="get" value="<?= $get ?>" />
				<?php } ?>

				<?php $order = Minz_Request::param('order', ''); ?>
				<?php if ($order != '') { ?>
				<input type="hidden" name="order" value="<?= $order ?>" />
				<?php } ?>

				<?php $state = Minz_Request::param('state', ''); ?>
				<?php if ($state != '') { ?>
				<input type="hidden" name="state" value="<?= $state ?>" />
				<?php } ?>

				<button class="btn" type="submit"><?= _i('search') ?></button>
			</div>
		</form>
		<?php } ?>
	</div>

	<?php if (FreshRSS_Auth::hasAccess()) { ?>
	<nav class="item configure">
		<div class="dropdown">
			<div id="dropdown-configure" class="dropdown-target"></div>
			<a class="btn dropdown-toggle" href="#dropdown-configure"><?= _i('configure') ?></a>
			<ul class="dropdown-menu scrollbar-thin">
				<li class="dropdown-header-close"><a class="toggle_aside" href="#close"><?= _i('close') ?></a></li>

				<li class="item dropdown-section">
					<div class="dropdown-section-title">
						<?= _t('gen.menu.account') ?>: <?= htmlspecialchars(Minz_Session::param('currentUser', '_'), ENT_NOQUOTES, 'UTF-8') ?>
					</div>
					<ul>
						<li class="item"><a href="<?= _url('user', 'profile') ?>"><?= _t('gen.menu.user_profile') ?></a></li>
						<?php if (FreshRSS_Auth::accessNeedsAction()): ?>
						<li class="item"><a class="signout" href="<?= _url('auth', 'logout') ?>"><?= _t('gen.auth.logout'); ?><?= _i('logout') ?></a></li>
						<?php else: ?>
						<li class="item"><span class="signout">(<?= htmlspecialchars(Minz_Session::param('currentUser', '_'), ENT_NOQUOTES, 'UTF-8') ?>)</span></li>
						<?php endif; ?>
					</ul>
				</li>
				<li class="item dropdown-section">
					<div class="dropdown-section-title">
						<?= _t('gen.menu.configuration') ?>
					</div>
					<ul>
						<li class="item"><a href="<?= _url('configure', 'display') ?>"><?= _t('gen.menu.display') ?></a></li>
						<li class="item"><a href="<?= _url('configure', 'reading') ?>"><?= _t('gen.menu.reading') ?></a></li>
						<li class="item"><a href="<?= _url('configure', 'archiving') ?>"><?= _t('gen.menu.archiving') ?></a></li>
						<li class="item"><a href="<?= _url('configure', 'integration') ?>"><?= _t('gen.menu.sharing') ?></a></li>
						<li class="item"><a href="<?= _url('configure', 'shortcut') ?>"><?= _t('gen.menu.shortcuts') ?></a></li>
						<li class="item"><a href="<?= _url('configure', 'queries') ?>"><?= _t('gen.menu.queries') ?></a></li>
						<li class="item"><a href="<?= _url('extension', 'index') ?>"><?= _t('gen.menu.extensions') ?></a></li>
						<?= Minz_ExtensionManager::callHook('menu_configuration_entry') ?>
					</ul>
				</li>
				<?php if (FreshRSS_Auth::hasAccess('admin')) { ?>
				<li class="item dropdown-section">
					<div class="dropdown-section-title">
						<?= _t('gen.menu.admin') ?>
					</div>
					<ul>
						<li class="item"><a href="<?= _url('configure', 'system') ?>"><?= _t('gen.menu.system') ?></a></li>
						<li class="item"><a href="<?= _url('user', 'manage') ?>"><?= _t('gen.menu.user_management') ?></a></li>
						<li class="item"><a href="<?= _url('auth', 'index') ?>"><?= _t('gen.menu.authentication') ?></a></li>
						<li class="item"><a href="<?= _url('update', 'checkInstall') ?>"><?= _t('gen.menu.check_install') ?></a></li>
						<?php if (!FreshRSS_Context::$system_conf->disable_update) { ?>
						<li class="item"><a href="<?= _url('update', 'index') ?>"><?= _t('gen.menu.update') ?></a></li>
						<?php } ?>
						<?= Minz_ExtensionManager::callHook('menu_admin_entry') ?>
					</ul>
				</li>
				<?php } ?>

				<li class="item dropdown-section">
					<ul>
						<li class="item"><a href="<?= _url('index', 'logs') ?>"><?= _t('gen.menu.logs') ?></a></li>
						<li class="item"><a href="<?= _url('index', 'about') ?>"><?= _t('gen.menu.about') ?></a></li>
						<?= Minz_ExtensionManager::callHook('menu_other_entry') ?>
					</ul>
				</li>
			</ul>
			<a class="dropdown-close" href="#close">❌</a>
		</div>
	</nav>
	<?php } elseif (FreshRSS_Auth::accessNeedsAction()) { ?>
	<div class="item configure">
		<a class="signin" href="<?= _url('auth', 'login') ?>"><?= _i('login') ?><?= _t('gen.auth.login') ?></a>
	</div>
	<?php } ?>
</header>
