<?php
	/** @var FreshRSS_View $this */
	$this->partial('aside_configure');
?>

<main class="post">
	<div class="link-back-wrapper">
		<a class="link-back" href="<?= _url('index', 'index') ?>"><?= _t('gen.action.back_to_rss_feeds') ?></a>
	</div>

	<h1><?= _t('admin.update') ?></h1>

	<p>
		<?= _i('help') ?> <?= _t('admin.update.current_version', FRESHRSS_VERSION) ?>
	</p>

	<p>
		<?= _t('admin.update.last', $this->last_update_time) ?>
	</p>

	<?php if (!empty($this->message)) { ?>
	<?php
		$class = 'alert-warn';
		switch ($this->message['status']) {
		case 'bad':
			$class = 'alert-error';
			break;
		case 'latest':
			$class = 'alert-success';
			break;
		default:
			$class = 'alert-warn';
			break;
		}
	?>
	<p class="alert <?= $class ?>">
		<span class="alert-head"><?= $this->message['title'] ?></span>
		<?= $this->message['body'] ?>
	</p>
	<?php } ?>

	<?php
		if (empty($this->message) || $this->message['status'] !== 'good') {
	?>
	<p>
		<a href="<?= _url('update', 'check') ?>" class="btn"><?= _t('admin.update.check') ?></a>
	</p>
	<?php } ?>

	<?php if ($this->update_to_apply) { ?>
	<a class="btn btn-important" href="<?= _url('update', 'apply') ?>"><?= _t('admin.update.apply') ?></a>
	<?php } ?>
</main>
