<?php /** @var FreshRSS_View $this */ ?>
<?php
$result = array(
	'feeds' => array(),
	'tags' => array(),
);
foreach ($this->categories as $cat) {
	foreach ($cat->feeds() as $feed) {
		$result['feeds'][$feed->id()] = $feed->nbNotRead();
	}
}
foreach ($this->tags as $tag) {
	$result['tags'][$tag->id()] = $tag->nbUnread();
}
echo json_encode($result);
