<?php
	/** @var FreshRSS_View $this */
	$this->partial('aside_subscription');
?>

<main class="post ">
	<div class="link-back-wrapper">
		<a class="link-back" href="<?= _url('index', 'index') ?>"><?= _t('gen.action.back_to_rss_feeds') ?></a>
	</div>

	<h1><?= _t('admin.stats.repartition') ?></h1>

	<select id="feed_select" class="select-change">
		<option data-url="<?= _url('stats', 'repartition') ?>"><?= _t('admin.stats.all_feeds') ?></option>
	<?php foreach ($this->categories as $category) {
		$feeds = $category->feeds();
		if (!empty($feeds)) {
			echo '<optgroup label="', $category->name(), '">';
			foreach ($feeds as $feed) {
				if ($this->feed && $feed->id() == $this->feed->id()) {
					echo '<option value="', $feed->id(), '" selected="selected" data-url="',
						_url('stats', 'repartition', 'id', $feed->id()), '">', $feed->name(), '</option>';
				} else {
					echo '<option value="', $feed->id(), '" data-url="',
						_url('stats', 'repartition', 'id', $feed->id()), '">', $feed->name(), '</option>';
				}
			}
			echo '</optgroup>';
		}
	}?>
	</select>

	<?php if ($this->feed) {?>
		<a class="btn" href="<?= _url('subscription', 'feed', 'id', $this->feed->id()) ?>">
			<?= _i('configure') ?> <?= _t('gen.action.manage') ?>
		</a>
	<?php }?>

	<div class="stat-grid">
		<div class="stat">
			<table>
			<tr>
				<th><?= _t('admin.stats.status_total') ?></th>
				<th><?= _t('admin.stats.status_read') ?></th>
				<th><?= _t('admin.stats.status_unread') ?></th>
				<th><?= _t('admin.stats.status_favorites') ?></th>
			</tr>
			<tr>
				<td class="numeric"><?= $this->repartition['total'] ?></td>
				<td class="numeric"><?= $this->repartition['count_reads'] ?></td>
				<td class="numeric"><?= $this->repartition['count_unreads'] ?></td>
				<td class="numeric"><?= $this->repartition['count_favorites'] ?></td>
			</tr>
			</table>
		</div>

		<div class="stat">
			<h2><?= _t('admin.stats.entry_per_hour', $this->averageHour) ?></h2>
			<div>
				<canvas id="statsEntriesPerHour"></canvas>
				<script class="jsonData-stats" type="application/json">
				<?php
				echo json_encode(array(
					'canvasID' 		=> 'statsEntriesPerHour',
					'charttype' 	=> 'bar',
					'data' 			=> $this->repartitionHour,
					'label' 		=> _t('admin.stats.entry_count'),
					'xAxisLabels' 	=> $this->hours24Labels
				), JSON_UNESCAPED_UNICODE);
				?></script>
			</div>
		</div>

		<div class="stat half">
			<h2><?= _t('admin.stats.entry_per_day_of_week', $this->averageDayOfWeek) ?></h2>
			<div>
				<canvas id="statsEntriesPerDayOfWeek"></canvas>
				<script class="jsonData-stats" type="application/json">
				<?php
				echo json_encode(array(
					'canvasID' 		=> 'statsEntriesPerDayOfWeek',
					'charttype' 	=> 'bar',
					'data' 			=> $this->repartitionDayOfWeek,
					'label' 		=> _t('admin.stats.entry_count'),
					'xAxisLabels' 	=> $this->days,
				), JSON_UNESCAPED_UNICODE);
				?></script>
			</div>
		</div>

		<div class="stat half">
			<h2><?= _t('admin.stats.entry_per_month', $this->averageMonth) ?></h2>
			<div>
				<canvas id="statsEntriesPerMonth"></canvas>
				<script class="jsonData-stats" type="application/json">
				<?php
				echo json_encode(array(
					'canvasID' 		=> 'statsEntriesPerMonth',
					'charttype' 	=> 'bar',
					'data' 			=> $this->repartitionMonth,
					'label' 		=> _t('admin.stats.entry_count'),
					'xAxisLabels' 	=> $this->months,
				), JSON_UNESCAPED_UNICODE);
				?></script>
			</div>
		</div>
	</div>
</main>

<script src="../scripts/statsWithChartjs.js?<?= @filemtime(PUBLIC_PATH . '/scripts/statsWithChartjs.js') ?>"></script>
