@charset "UTF-8";

/*=== GENERAL */
/*============*/
html, body {
	background: #fafafa;
	color: black;
	font-family: "OpenSans", "Cantarell", "Helvetica", "Arial", "PingFang SC", "Microsoft YaHei", sans-serif;
	font-size: 92%;
}

/*=== Links */
a, button.as-link {
	color: #d18114;
	outline: none;
}

legend {
	margin: 20px 0 5px;
	padding: 5px 0;
	font-size: 1.4em;
	border-bottom: 1px solid #ddd;
}

label {
	min-height: 25px;
	padding: 5px 0;
	cursor: pointer;
}

textarea {
	width: 360px;
	height: 100px;
}

input, select, textarea {
	padding: 5px;
	background: #fff;
	color: #222;
	border: 1px solid #ccc;
	border-radius: 3px;
	box-shadow: 0 1px 2px #ccc inset, 0 1px #fff;
	min-height: 25px;
	line-height: 25px;
	vertical-align: middle;
}

option {
	padding: 0 .5em;
}

input:focus, select:focus, textarea:focus {
	color: #0f0f0f;
	border: solid 1px #e7ab34;
	box-shadow: 0 0 3px #e7ab34;
}

input:invalid, select:invalid {
	border-color: #f00;
	box-shadow: 0 0 2px 2px #fdd inset;
}

input:disabled, select:disabled {
	background: #eee;
}

/*=== Tables */
table {
	border-collapse: collapse;
}

th, td {
	border: 1px solid #ddd;
}

th {
	background: #f6f6f6;
}

form td,
form th {
	font-weight: normal;
	text-align: center;
}

/*=== COMPONENTS */
/*===============*/
/*=== Forms */
.form-group.form-actions {
	padding: 5px 0;
	background: #f4f4f4;
	border-top: 1px solid #ddd;
}

.form-group.form-actions .btn {
	margin: 0 10px;
	border-radius: 4px;
	box-shadow: 0 1px rgba(255,255,255,0.08) inset;
}

.form-group .group-name {
	padding: 10px 0;
}

.form-group .group-controls {
	min-height: 25px;
	padding: 5px 0;
}

/*=== Buttons */
button.as-link[disabled] {
	color: #555 !important;
}

.dropdown-menu .input select, .dropdown-menu .input input {
	margin: 0 auto 5px;
	padding: 2px 5px;
	background: #444;
	color: #fff;
	border: solid 1px #171717;
	border-radius: 3px;
	box-shadow: 0 2px 2px #222 inset, 0px 1px rgba(255, 255, 255, 0.08);
}

.stick input,
.stick .btn {
	border-radius: 0;
}

.stick .btn:first-child,.stick input:first-child {
	border-radius: 6px 0 0 6px;
}

.stick .btn:last-child, .stick input:last-child {
	border-radius: 0 6px 6px 0;
}

.stick .btn + .btn,
.stick .btn + input,
.stick .btn + .dropdown > .btn,
.stick input + .btn,
.stick input + input,
.stick input + .dropdown > .btn,
.stick .dropdown + .btn,
.stick .dropdown + input,
.stick .dropdown + .dropdown > .btn {
	border-left: none;
}

.stick .btn + .dropdown > .btn {
	border-left: none;
	border-radius: 0 3px 3px 0;
}

.btn {
	margin: 0;
	padding: 5px 10px;
	background: linear-gradient(0deg, #ede7de 0%, #fff 100%) #ede7de;
	background: -webkit-linear-gradient(bottom, #ede7de 0%, #fff 100%);
	display: inline-block;
	color: #222;
	font-size: 0.9rem;
	border: solid 1px #ccc;
	border-radius: 4px;
	min-height: 37px;
	min-width: 15px;
	text-shadow: 0px -1px rgba(255,255,255,0.08);
	vertical-align: middle;
	cursor: pointer;
	overflow: hidden;
}

a.btn {
	min-height: 25px;
	line-height: 25px;
}

.btn:hover {
	text-shadow: 0 0 2px #fff;
	text-decoration: none;
}

.btn.active,.btn:active,.dropdown-target:target ~ .btn.dropdown-toggle {
	background: linear-gradient(180deg, #ede7de 0%, #fff 100%) #ede7de;
	background: -webkit-linear-gradient(top, #ede7de 0%, #fff 100%);
}

.nav_menu .btn.active, .nav_menu .btn:active, .nav_menu .dropdown-target:target ~ .btn.dropdown-toggle {
	background: linear-gradient(180deg, #ede7de 0%, #f6f6f6 100%) #ede7de;
	background: -webkit-linear-gradient(top, #ede7de 0%, #f6f6f6 100%);
	border: solid 1px #ccc;
	border-radius: 4px;
	box-shadow: 0 1px #fff;
}

.nav_menu .btn {
	background: transparent;
	border: 0;
}

.read_all {
	color: #222;
}

.btn.dropdown-toggle[href="#dropdown-configure"] {
	background: linear-gradient(0deg, #ede7de 0%, #fff 100%) #ede7de;
	background: -webkit-linear-gradient(bottom, #ede7de 0%, #fff 100%);
	border: solid 1px #ccc;
	border-radius: 4px;
	box-shadow: 0 1px #fff;
}

.btn.dropdown-toggle:active {
	background: transparent;
}

.btn-important {
	background: linear-gradient(180deg, #e4992c 0%, #d18114 100%) #e4992c;
	background: -webkit-linear-gradient(top, #e4992c 0%, #d18114 100%);
	color: #fff;
	border-radius: 4px;
	box-shadow: 0 1px rgba(255,255,255,0.08) inset;
	text-shadow: 0px -1px rgba(255,255,255,0.08);
	font-weight: normal;
}

.btn-important:active {
	background: linear-gradient(0deg, #e4992c 0%, #d18114 100%) #e4992c;
	background: -webkit-linear-gradient(bottom, #e4992c 0%, #d18114 100%);
}

.btn-important .icon {
	filter: brightness(3);
}

.btn-attention {
	background: #e95b57;
	background: linear-gradient(to bottom, #e95b57, #bd362f);
	background: -webkit-linear-gradient(top, #e95b57 0%, #bd362f 100%);
	color: #fff;
	border: 1px solid #c44742;
	text-shadow: 0px -1px 0px #666;
}

.btn-attention:hover {
	background: linear-gradient(to bottom, #d14641, #bd362f);
	background: -webkit-linear-gradient(top, #d14641 0%, #bd362f 100%);
}

.btn-attention:active {
	background: #bd362f;
	box-shadow: none;
}

.btn[type="reset"] {
	background: linear-gradient(180deg, #222 0%, #171717 100%) #171717;
	background: -webkit-linear-gradient(top, #222 0%, #171717 100%);
	color: #fff;
	box-shadow: 0 -1px rgba(255,255,255,0.08) inset;
}
/*=== Navigation */
.nav-list {
	font-size: 0.9rem;
}

.nav-list .item,
.nav-list .item.nav-header {
	min-height: 2.5em;
	line-height: 2.5;
}

.nav-list .item a:hover {
	text-shadow: 0 0 2px rgba(255,255,255,0.28);
	color: #fff;
}

.nav-list .item.active {
	margin: 0;
	background: linear-gradient(180deg, #222 0%, #171717 100%) repeat scroll 0% 0% #171717;
	background: -webkit-linear-gradient(180deg, #222 0%, #171717 100%);
	box-shadow: -1px 2px 2px #171717, 0px 1px rgba(255, 255, 255, 0.08) inset;
	border-width: medium medium 1px;
	border-style: none none solid;
	border-color: -moz-use-text-color -moz-use-text-color #171717;
}

.nav-list .item.active a {
	color: #d18114;
}

.nav-list .item > a {
	padding: 0 1rem;
	color: #ccc;
}

.nav-list a:hover {
	text-decoration: none;
}

.nav-list .nav-header {
	padding: 0 1rem;
	background: transparent;
	color: #222;
}

.nav-list .nav-form {
	padding: 3px;
	text-align: center;
}

/*=== Dropdown */
.dropdown-menu {
	margin: 5px 0 0;
	padding: 0.5rem 0 0.25rem 0;
	background: #222;
	font-size: 0.8rem;
	border: 1px solid #171717;
	border-radius: 4px;
	box-shadow: 0 0 3px #000;
	text-align: left;
}

.dropdown-menu::after {
	border-color: #171717;
}

.dropdown-header,
.dropdown-section .dropdown-section-title {
	padding: 0 5px 5px;
	color: #ccc;
	font-weight: bold;
}

.dropdown-menu .item > a,
.dropdown-menu .item > span,
.dropdown-menu .item > .as-link {
	padding: 0 22px;
	line-height: 2.5em;
	color: #ccc;
	font-size: 0.8rem;
}

.dropdown-menu .dropdown-section .item > a,
.dropdown-menu .dropdown-section .item > span,
.dropdown-menu .dropdown-section .item > .as-link {
	padding-left: 2rem;
}

.dropdown-menu .dropdown-section .item:last-child {
	margin-bottom: 0.5rem;
}

.dropdown-menu .item > a:hover,
.dropdown-menu .item > button:hover:not([disabled]),
.dropdown-menu .item > label:hover:not(.noHover) {
	background: #171717;
	color: #fff;
}

.dropdown-menu > .item > label {
	color: #ccc;
}

.dropdown-menu > .item[aria-checked="true"] > a::before {
	font-weight: bold;
	margin: 0 0 0 -14px;
}

.dropdown-menu > .item:hover > a {
	color: #fff;
	text-decoration: none;
}

.item ~ .dropdown-header,
.dropdown-section ~ .dropdown-section,
.item.separator {
	border-top-color: rgba(255,255,255,0.08);
}

/*=== Alerts */
.alert {
	background: #f4f4f4;
	color: #aaa;
	font-size: 0.9em;
	border: 1px solid #ccc;
	border-right: 1px solid #aaa;
	border-bottom: 1px solid #aaa;
	border-radius: 5px;
	text-shadow: 0 0 1px #eee;
}

.alert-head {
	font-size: 1.15em;
}

.alert > a {
	color: inherit;
	text-decoration: underline;
}

.alert-warn {
	background: #ffe;
	color: #c95;
	border: 1px solid #eeb;
}

.alert-success {
	background: #dfd;
	color: #484;
	border: 1px solid #cec;
}

.alert-error {
	background: #fdd;
	color: #844;
	border: 1px solid #ecc;
}

/*=== Pagination */
.pagination {
	background: #fafafa;
	color: #333;
}

.pagination .item a {
	color: #333;
}

.pagination .item a:hover {
	background: #ddd;
	color: inherit
}

.pagination:first-child .item {
	border-bottom: 1px solid #aaa;
}

.pagination:last-child .item {
	border-top: 1px solid #ddd;
}

/*=== Boxes */
.box {
	background: #ede7de;
	border-radius: 4px;
	box-shadow: 0 1px #fff;
}

.box .box-title {
	margin: 0;
	padding: 5px 10px;
	background: linear-gradient(0deg, #ede7de 0%, #fff 100%) #171717;
	background: -webkit-linear-gradient(bottom, #ede7de 0%, #fff 100%);
	color: #888;
	font-size: 1.1rem;
	border-radius: 4px 4px 0 0;
	box-shadow: 0px -1px #fff inset,0 -2px #ccc inset;
	text-shadow: 0 1px #ccc;
	font-weight: normal;
}

.box .box-title .configure {
	margin-right: 4px;
}

.box .box-content {
	padding-left: 30px;
	max-height: 260px;
}

.box .box-content .item {
	font-size: 0.9rem;
}

/*=== Tree */
.tree {
	margin: 10px 0;
}

.tree-folder-title {
	position: relative;
	padding: 0 10px;
	line-height: 2.5rem;
	font-size: 0.9rem;
}

.tree-folder-title .title {
	background: inherit;
	color: #fff;
}

.tree-folder-title .title:hover {
	text-decoration: none;
}

.tree-folder.active .tree-folder-title {
	background: linear-gradient(180deg, #222 0%, #171717 100%) #171717;
	background: -webkit-linear-gradient(top, #222 0%, #171717 100%);
	color: #fff;
	box-shadow: 0px 1px #171717, 0px 1px rgba(255, 255, 255, 0.08) inset;
	text-shadow: 0 0 2px rgba(255,255,255,0.28);
}

.tree-folder-items {
	padding: 8px 0;
	background: #171717;
	box-shadow: 0 4px 4px #171717 inset, 0 1px rgba(255,255,255,0.08),0 -1px rgba(255,255,255,0.08);
}

.tree-folder-items > .item {
	font-size: 0.8rem;
}

.tree-folder-items > .item.active {
	margin: 0px 8px;
	background: linear-gradient(180deg, #222 0%, #171717 100%) #171717;
	background: -webkit-linear-gradient(top, #222 0%, #171717 100%);
	border-radius: 4px;
	box-shadow: 0px 1px #171717, 0px 1px rgba(255, 255, 255, 0.08) inset, 0 2px 2px #111;
}

.tree-folder-items > .item > a {
	text-decoration: none;
	color: #fff;
	font-size: 0.92em;
}

/*=== Scrollbar */

@supports (scrollbar-width: thin) {
	#sidebar {
		scrollbar-color: rgba(255, 255, 255, 0.05) rgba(0, 0, 0, 0.0);
	}

	#sidebar:hover {
		scrollbar-color: rgba(255, 255, 255, 0.3) rgba(0, 0, 0, 0.0);
	}
}

@supports not (scrollbar-width: thin) {
	#sidebar::-webkit-scrollbar-thumb {
		background: rgba(255, 255, 255, 0.1);
	}

	#sidebar:hover::-webkit-scrollbar-thumb {
		background: rgba(255, 255, 255, 0.3);
	}
}

/*=== STRUCTURE */
/*===============*/
/*=== Header */
.header {
	background: linear-gradient(0deg, #ede7de 0%, #fff 100%) #ede7de;
	background: -webkit-linear-gradient(bottom, #ede7de 0%, #fff 100%);
	height: 55px;
}

.header > .item {
	padding: 0;
	vertical-align: middle;
	text-align: center;
}

.header > .item.title .logo {
	margin: 0.5em 0;
	height: 35px;
	filter: invert(80%);
}

.header > .item.title {
	width: 250px;
}

.header > .item.search input {
	width: 350px;
}

/*=== Body */
#global {
	background: #ede7de;
	height: calc(100% - 55px);
}

.aside {
	background: #222;
	width: 235px;
	border-top: 1px solid #ccc;
	border-radius: 0px 12px 0px 0px;
	box-shadow: 0px -1px #fff, 0 2px 2px #171717 inset;
}

.aside.aside_feed {
	padding: 10px 0;
	text-align: center;
}

.aside.aside_feed .tree {
	margin: 10px 0 50px;
}

/*=== Aside main page (categories) */
.aside.aside_feed .category .title:not([data-unread="0"])::after {
	background-color: #d18114;
}

.aside.aside_feed .feed .item-title:not([data-unread="0"])::after {
	background-color: #222;
	color: #ccc;
	border: 1px solid #333;
}

.aside_feed .btn-important {
	border: none;
}

/*=== Aside main page (feeds) */
.feed.item.empty,
.feed.item.empty > a {
	color: #e67e22;
}

.feed.item.error,
.feed.item.error > a {
	color: #bd362f;
}

.aside_feed .tree-folder-items .dropdown-menu::after {
	left: 2px;
}

.aside_feed .tree-folder-items .item .dropdown-target:target ~ .dropdown-toggle > .icon,
.aside_feed .tree-folder-items .item:hover .dropdown-toggle > .icon,
.aside_feed .tree-folder-items .item.active .dropdown-toggle > .icon {
	border-radius: 3px;
}

/*=== Configuration pages */
.post {
	padding: 10px 50px;
	font-size: 0.9em;
}

.post form {
	margin: 10px 0;
}

.post.content {
	max-width: 550px;
}

/*=== Prompt (centered) */
.prompt {
	text-shadow: 0 1px rgba(255,255,255,0.08);
}

.prompt .form-group {
	margin-bottom: 1rem;
}

.prompt .form-group::after {
	display: none;
}

.prompt .form-group.form-group-actions {
	display: flex;
	margin-top: 2rem;
	align-items: center;
	justify-content: space-between;
}

.prompt input#username,.prompt input#passwordPlain {
	background: #fff;
	border: solid 1px #ccc;
	box-shadow: 0 4px -4px #ccc inset,0px 1px rgba(255, 255, 255, 0.08);
}

.prompt input#username:focus,.prompt input#passwordPlain:focus {
	border: solid 1px #e7ab34;
	box-shadow: 0 0 3px #e7ab34;
}

.prompt .btn.btn-important {
	padding-left: 1.5rem;
	padding-right: 1.5rem;
	font-size: 1.1rem;
}

/*=== New article notification */
#new-article {
	background: #0084cc;
	text-align: center;
	font-size: 0.9em;
}

#new-article > a {
	line-height: 3em;
	color: #fff;
	font-weight: bold;
}

#new-article > a:hover {
	text-decoration: none;
	background: #06c;
}

/*=== Day indication */
.day {
	padding: 0 10px;
	background: linear-gradient(0deg, #ede7de 0%, #c2bcb3 100%) #ede7de;
	background: -webkit-linear-gradient(bottom, #c2bcb3 0%, #fff 100%);
	color: #666;
	box-shadow: 0 1px #bdb7ae inset, 0 -1px rgba(255,255,255,0.28) inset;
	font-style: italic;
	line-height: 3em;
	text-shadow: 0 1px rgba(255,255,255,0.28);
	text-align: center;
}

#new-article + .day {
	border-top: none;
}

.day .name {
	display: none;
}

/*=== Index menu */
.nav_menu {
	padding: 5px 0;
	background: #ede7de;
	border-bottom: 1px solid #ccc;
	box-shadow: 0 -1px rgba(255, 255, 255, 0.28) inset;
	text-align: center;
}

#panel >.nav_menu {
	background: linear-gradient(0deg, #ede7de 0%, #fff 100%) #ede7de;
	background: -webkit-linear-gradient(bottom, #ede7de 0%, #fff 100%);
}

#panel > .nav_menu > #nav_menu_read_all {
	background: linear-gradient(0deg, #ede7de 0%, #fff 100%) #ede7de;
	background: -webkit-linear-gradient(bottom, #ede7de 0%, #fff 100%);
	border: 1px solid #ccc;
	border-radius: 4px;
	box-shadow: 0px 1px #fff;
}

#panel > .nav_menu > #nav_menu_read_all .dropdown > .btn.dropdown-toggle {
	border: none;
	border-left: solid 1px #ccc;
	border-radius: 0 4px 4px 0;
}

/*=== Feed articles */
.flux_content {
	background: #fff;
	border-radius: 10px;
}

.flux {
	background: #ede7de;
}

.flux .flux_header:hover {
	background: #f9f7f4;
}

.flux:not(.current):hover .item.title {
	background: #f9f7f4;
}

.flux.current .flux .item.title a {
	text-shadow: 0 0 2px #ccc;
}

.flux.favorite {
	background: #fff6da;
}

.flux.favorite:not(.current):hover {
	background: #f9f7f4;
}

.flux.favorite:not(.current):hover .item.title {
	background: #f9f7f4;
}

.flux.current {
	margin: 3px 6px;
	background: linear-gradient(0deg, #ede7de 0%, #fff 100%) #ede7de;
	background: -webkit-linear-gradient(bottom, #ede7de 0%, #fff 100%);
	border-radius: 10px;
	box-shadow: 0 -1px #fff inset, 0 2px #ccc;
}

.flux .item.title a {
	color: #aca8a3;
}

.flux.not_read .item.title a,
.flux.favorite .item.title a {
	color: #333;
}

.flux.not_read:not(.current):hover .item.title a {
	color: #50504f;
}

.flux.current .item.title a {
	color: #0f0f0f;
}

.flux_header {
	font-size: 0.8rem;
	border-top: 1px solid #ddd;
	box-shadow: 0 -1px rgba(255,255,255,0.28) inset;
	cursor: pointer;
}

.flux_header .title {
	font-size: 0.9rem;
}

.flux .item.date {
	color: #666;
	font-size: 0.7rem;
}

.flux .bottom {
	font-size: 0.8rem;
	text-align: center;
}

/*=== Content of feed articles */
.content {
	padding: 20px 10px;
}

.content > h1.title > a {
	color: #000;
}

.content hr {
	margin: 30px 10px;
	background: #ddd;
	height: 1px;
	border: 0;
	box-shadow: 0 2px 5px #ccc;
}

.content pre {
	margin: 10px auto;
	padding: 10px 20px;
	overflow: auto;
	background: #222;
	color: #fff;
	font-size: 0.9rem;
	border-radius: 3px;
}

.content code {
	padding: 2px 5px;
	background: #fafafa;
	color: #d14;
	border: 1px solid #eee;
	border-radius: 3px;
}

.content pre code {
	background: transparent;
	color: #fff;
	border: none;
}

.content blockquote {
	margin: 0;
	padding: 5px 20px;
	background: #fafafa;
	display: block;
	color: #333;
	border-top: 1px solid #ddd;
	border-bottom: 1px solid #ddd;
}

.content blockquote p {
	margin: 0;
}

/*=== Notification and actualize notification */
.notification {
	background: #222;
	color: #fff;
	font-size: 0.9em;
	border: none;
	border-radius: 0 0 12px 12px;
	box-shadow: 0px 0px 4px rgba(0,0,0,0.45), 0 -1px rgba(255,255,255,0.08) inset, 0 2px 2px #171717 inset;
	text-align: center;
	font-weight: bold;
	position: absolute;
	top: 0;
	vertical-align: middle;
}

.notification.good {
	color: #c95;
}

.notification.bad {
	background: #fdd;
	color: #844;
}

/*=== "Load more" part */
#bigMarkAsRead {
	background: #ede7de;
	color: #666;
	box-shadow: 0 1px rgba(255,255,255,0.28)inset;
	text-align: center;
	text-decoration: none;
	text-shadow: 0 -1px 0 #aaa;
}

#bigMarkAsRead:hover {
	background: #ede7de;
	background: radial-gradient(circle at 50% -25% , #ccc 0%, #ede7de 50%);
	color: #000;
}

#bigMarkAsRead:hover .bigTick {
	text-shadow: 0 0 10px #666;
}

.switch.active {
	background-color: #d18114;
}

/*=== Navigation menu (for articles) */
#nav_entries {
	background: linear-gradient(180deg, #222 0%, #171717 100%) #222;
	background: -webkit-linear-gradient(top, #222 0%, #171717 100%);
	width: 235px;
	border-top: 1px solid #171717;
	box-shadow: 0 1px rgba(255,255,255,0.08) inset, 0 -2px 2px #171717;
	text-align: center;
	line-height: 3em;
	table-layout: fixed;
}

/*=== READER VIEW */
/*================*/
#stream.reader .flux {
	background: #ede7de;
	color: #333;
	border: none;
}

#stream.reader .flux_content {
	background: none;
	border-radius: 0;
}

#stream.reader .flux .content {
	background-color: #fff;
	border-color: #ddd;
	border-radius: 10px;
	box-shadow: 0 -1px rgba(255,255,255,0.28) inset;
}

#stream.reader .flux .author {
	margin: 0 0 10px;
	color: #666;
	font-size: 90%;
}

/*=== GLOBAL VIEW */
/*================*/
#stream.global {
	padding: 24px 0;
	box-shadow: 0px 8px 8px #c2bcb3 inset;
}

.box.category .box-title {
	background: linear-gradient(0deg, #ede7de 0%, #fff 100%) #171717;
	background: -webkit-linear-gradient(bottom, #ede7de 0%, #fff 100%);
	font-size: 1.2rem;
	border-radius: none;
	box-shadow: 0px -1px #fff inset,0 -2px #ccc inset;
	line-height: 2em;
	text-shadow: 0 1px #ccc;
}

.box.category .box-title .title {
	font-weight: normal;
	text-decoration: none;
	text-align: left;
	color: #888;
}

.box.category:not([data-unread="0"]) .box-title .title {
	color: #222;
	font-weight: bold;
}

.box.category .title:not([data-unread="0"])::after {
	background: none;
	border: 0;
	position: absolute;
	top: 5px; right: 10px;
	font-weight: bold;
}

.box.category .item.feed:not(.empty):not(.error) .item-title {
	color: #222;
}

/*=== PANEL */
/*===========*/
#panel {
	background: #ede7de;
	border-radius: 8px;
	box-shadow: 0px 0px 4px #000;
}
/*=== DIVERS */
/*===========*/
.aside.aside_feed .nav-form input,.aside.aside_feed .nav-form select {
	width: 130px;
}

.aside.aside_feed .nav-form .dropdown .dropdown-menu {
	right: -20px;
}

.aside.aside_feed .nav-form .dropdown .dropdown-menu::after {
	right: 33px;
}

/*=== STATISTICS */
/*===============*/
.stat {
	margin: 10px 0 20px;
}

.stat th,
.stat td,
.stat tr {
	border: none;
}

.stat > table td,
.stat > table th {
	background: rgba(255,255,255,0.38);
	border-bottom: 1px solid #ccc;
	box-shadow: 0 1px #fff;
}

#slider.active {
	background: #f8f8f8;
	box-shadow: -4px 0 4px rgba(15, 15, 15, 0.55);
}

#close-slider.active {
	background: rgba(15, 15, 15, 0.35);
}

/*=== MOBILE */
/*===========*/

@media screen and (max-width: 840px) {
	.form-group .group-name {
		padding-bottom: 0;
	}

	.header {
		display: table;
	}

	.nav-login {
		display: none;
	}

	.aside {
		width: 0;
		border-top: none;
		box-shadow: 3px 0 3px #000;
		transition: width 200ms linear;
	}

	.aside:target {
		width: 235px;
	}

	.aside .toggle_aside,
	#panel .close,
	.dropdown-menu .toggle_aside {
		background: #171717;
		border-radius: 0 8px 0 8px;
		box-shadow: 0 1px rgba(255,255,255,0.08);
	}

	.aside.aside_feed {
		padding: 0;
	}

	.nav_menu .btn {
		margin: 5px 10px;
		padding: 3px 5px;
		min-height: 0;
	}

	.nav_menu .stick {
		margin: 0 10px;
	}

	.nav_menu .stick .btn {
		margin: 5px 0;
	}

	.nav_menu .search input {
		padding: 3px 5px;
		max-width: 97%;
		width: 90px;
	}

	.nav_menu .search input:focus {
		width: 400px;
	}

	.dropdown-target:target ~ .dropdown-toggle::after {
		background-color: #222;
		border-top: 1px solid #171717;
		border-left: 1px solid #171717;
	}

	.day .name {
		display: none;
	}

	.notification a.close {
		background: transparent;
		display: block;
		left: 0;
	}

	.notification a.close:hover {
		opacity: 0.5;
	}

	.notification a.close .icon {
		display: none;
	}

	#nav_entries {
		width: 100%;
	}

	.post {
		padding-left: 15px;
		padding-right: 15px;
	}

	#close-slider.active {
		background: #171717;
		box-shadow: 0 1px rgba(255,255,255,0.08)
	}
}

@media (max-width: 700px) {
	.nav-login {
		display: inline-block;
		width: 100%;
	}

	.nav_menu .search {
		display: inline-block;
	}
}
