@use "variables";

/*=== READER VIEW */
/*================*/
#stream.reader {
	.flux {
		background: variables.$grey-light;
		color: variables.$main-font-color;
		border: none;

		.content {
			background-color: variables.$white;
			border: none;

			.author {
				margin: 0 0 10px;
				color: variables.$grey-medium-dark;
				font-size: 90%;
			}
		}
	}
}
